@@ -1,5 +1,7 @@
 from __future__ import absolute_import, division, print_function
+
 import sys
+
 import py
 import _pytest
 import pytest
@@ -25,7 +27,7 @@ class TestNewAPI(object):
         cache = config.cache
         pytest.raises(TypeError, lambda: cache.set("key/name", cache))
         config.cache.set("key/name", 0)
-        config.cache._getvaluepath("key/name").write("123invalid")
+        config.cache._getvaluepath("key/name").write_bytes(b"123invalid")
         val = config.cache.get("key/name", -2)
         assert val == -2
 
@@ -148,6 +150,32 @@ def test_cache_reportheader(testdir):
     result.stdout.fnmatch_lines(["cachedir: .pytest_cache"])
 
 
+def test_cache_reportheader_external_abspath(testdir, tmpdir_factory):
+    external_cache = tmpdir_factory.mktemp(
+        "test_cache_reportheader_external_abspath_abs"
+    )
+
+    testdir.makepyfile(
+        """
+        def test_hello():
+            pass
+    """
+    )
+    testdir.makeini(
+        """
+    [pytest]
+    cache_dir = {abscache}
+    """.format(
+            abscache=external_cache
+        )
+    )
+
+    result = testdir.runpytest("-v")
+    result.stdout.fnmatch_lines(
+        ["cachedir: {abscache}".format(abscache=external_cache)]
+    )
+
+
 def test_cache_show(testdir):
     result = testdir.runpytest("--cache-show")
     assert result.ret == 0
@@ -813,3 +841,30 @@ class TestNewFirst(object):
                 "*test_1/test_1.py::test_1[2*",
             ]
         )
+
+
+class TestReadme(object):
+    def check_readme(self, testdir):
+        config = testdir.parseconfigure()
+        readme = config.cache._cachedir.joinpath("README.md")
+        return readme.is_file()
+
+    def test_readme_passed(self, testdir):
+        testdir.makepyfile(
+            """
+            def test_always_passes():
+                assert 1
+        """
+        )
+        testdir.runpytest()
+        assert self.check_readme(testdir) is True
+
+    def test_readme_failed(self, testdir):
+        testdir.makepyfile(
+            """
+            def test_always_passes():
+                assert 0
+        """
+        )
+        testdir.runpytest()
+        assert self.check_readme(testdir) is True
